@@ -1,3 +1,5 @@
+# pylint: skip-file
+
 """
 Defines the class that runs the server
 """
@@ -17,12 +19,13 @@ import sqlite3
 import cherrypy
 
 from cmstoolbox import sitereadiness
+from cmstoolbox import checkexists
+
 
 from workflowwebtools import workflowinfo
 from workflowwebtools import serverconfig
 from workflowwebtools import manageactions
 from workflowwebtools import manageusers
-from workflowwebtools import showlog
 from workflowwebtools import reasonsmanip
 from workflowwebtools import listpage
 from workflowwebtools import globalerrors
@@ -134,30 +137,6 @@ class WorkflowTools(object):
             data['workflow_history'], data['all_errors'])
         return render('complete.html')
 
-    @cherrypy.expose
-    def showlog(self, search='', module='', limit=50):
-        """
-        This page, located at ``https://localhost:8080/showlog``,
-        returns logs that are stored in an elastic search server.
-        If directed here from :ref:`workflow-view-ref`, then
-        the search will be for the relevant workflow.
-
-        :param str search: The search string
-        :param str module: The module to look at, if only interested in one
-        :param int limit: The limit of number of logs to show on a single page
-        :returns: the logs from elastic search
-        :rtype: str
-        """
-        logdata = showlog.give_logs(search, module, int(limit))
-        if isinstance(logdata, dict):
-            return render('showlog.html',
-                          logdata=logdata,
-                          search=search,
-                          module=module,
-                          limit=limit)
-
-        return logdata
-
     @cherrypy.expose
     def globalerror2(self, reset=False):
         if reset:
@@ -185,6 +164,10 @@ class WorkflowTools(object):
             return "none"
         return "acted" if status else "pending"
 
+    @cherrypy.expose
+    @cherrypy.tools.json_out()
+    def getstatus(self, workflow):
+        return {'status': self.get_status(workflow).capitalize()}
 
     def get(self, workflow):
         self.wflock.acquire()
@@ -214,11 +197,11 @@ class WorkflowTools(object):
              "status": self.get_status(workflow),
              "errors": obj['obj'].sum_errors()
             }
-            for workflow, obj in workflow_objs.iteritems()
+            for workflow, obj in workflow_objs.items()
             ]
 
         self.lock.acquire()
-        for workflow, obj in workflow_objs.iteritems():
+        for workflow, obj in workflow_objs.items():
             if workflow not in self.workflows:
                 self.workflows[workflow] = obj['obj']
         self.lock.release()
@@ -231,10 +214,12 @@ class WorkflowTools(object):
 
     @cherrypy.expose
     @cherrypy.tools.json_in()
+    @cherrypy.tools.json_out()
     def submit2(self):
         input_json = cherrypy.request.json
-        manageactions.submit2(input_json['documents'])
-        return 'Done'
+        manageactions.submit2(cherrypy.request.login, input_json['documents'])
+        self.update_statuses()
+        return {'message': 'Done'}
 
 
     @cherrypy.expose
@@ -333,7 +318,7 @@ class WorkflowTools(object):
                 'long': longreason
             }
             for shortreason, longreason in
-            sorted(reasonsmanip.reasons_list().iteritems())
+            sorted(reasonsmanip.reasons_list().items())
         ]
 
 
@@ -346,17 +331,17 @@ class WorkflowTools(object):
         output = []
 
         # Need to track total sites, so we need to do nested loops here
-        for step, ecs in sorted(errors.iteritems()):
+        for step, ecs in sorted(errors.items()):
             allsites = set()
 
             codes = []
             for code, sites in sorted([
                     (-1 if code == 'NotReported' else int(code), sites)
-                    for code, sites in ecs.iteritems()]):
+                    for code, sites in ecs.items()]):
 
                 sites = {
                     site: (num or int(code < 0))
-                    for site, num in sorted(sites.iteritems())
+                    for site, num in sorted(sites.items())
                 }
                 allsites.update(sites.keys())
 
@@ -392,7 +377,7 @@ class WorkflowTools(object):
         This should help operators understand what the error means.
 
         At the top of the page, there are links back for :ref:`global-view-ref`,
-        :ref:`show-logs-ref`, related JIRA tickets,
+        workflow logs, related JIRA tickets,
         and ReqMgr2 information about the workflow and prep ID.
 
         The main function of this page is to submit actions.
@@ -508,7 +493,8 @@ class WorkflowTools(object):
                         'status': status,
                         'drain': drain
                     }
-                    for site, status, drain in sitereadiness.i_site_readiness()
+                    for site, status, drain in sitereadiness.i_site_readiness() \
+                    if not site.startswith('T3')
                 ]
         finally:
             self.readinesslock.release()
@@ -551,6 +537,9 @@ class WorkflowTools(object):
         """
         output = {'similar': [], 'acted': []}
 
+        if serverconfig.config_dict()['cluster'].get('skip'):
+            return output
+
         self.seeworkflowlock.acquire()
 
         try:
@@ -597,14 +586,14 @@ class WorkflowTools(object):
         self.seeworkflowlock.acquire()
 
         try:
-            max_error = classifyerrors.get_max_errorcode(workflow, cherrypy.session)
-            main_error_class = classifyerrors.classifyerror(max_error, workflow, cherrypy.session)
+            max_error = classifyerrors.get_max_errorcode(self.get(workflow))
+            main_error_class = classifyerrors.classifyerror(max_error, self.get(workflow))
 
             output = {
                 'maxerror': max_error,
-                'types': main_error_class[0],
-                'recommended': main_error_class[1],
-                'params': main_error_class[2]
+                'types': main_error_class['types'],
+                'recommended': main_error_class['recommended'],
+                'params': main_error_class['params_string']
             }
 
         finally:
@@ -684,7 +673,7 @@ class WorkflowTools(object):
             for workflow in workflows:
                 # Check sites of recovered workflows
                 if check_actions[workflow]['Action'] in ['acdc', 'recovery']:
-                    for subtask, params in check_actions[workflow]['Parameters'].iteritems():
+                    for subtask, params in check_actions[workflow]['Parameters'].items():
                         # Empty sites are noted
                         if not params.get('sites'):
                             blank_sites_subtask.append('/%s/%s' % (workflow, subtask))
@@ -792,6 +781,7 @@ class WorkflowTools(object):
 
         return output
 
+
     @cherrypy.expose
     def explainerror(self, errorcode='0', workflowstep='/'):
         """Returns an explaination of the error code, along with a link returning to table
@@ -981,3 +971,75 @@ class WorkflowTools(object):
                       sitename=sitename,
                       acted_workflows=acted,
                       info=info)
+
+    @cherrypy.expose
+    @cherrypy.tools.json_out()
+    def problem_files(self, workflow):
+        # Which errors do we want to check files:
+        errors = [84, 85, 92, 8020, 8021, 8028]
+
+        files_to_check = set()
+
+        wfi = self.get(workflow)
+
+        for error in errors:
+            for file_to_add in classifyerrors.classifyerror(error, wfi)['list_of_params']:
+                files_to_check.add(file_to_add)
+
+        return sorted(files_to_check)
+
+    @cherrypy.expose
+    @cherrypy.tools.json_out()
+    def file_exists(self, filename):
+        output = {'xrdfs_locate': int(checkexists.exists(filename))}
+
+        return output
+
+    def auto_acdc(self, user, workflow, dry):
+        params = self.submissionparams(workflow)
+
+        site_map = {site['site']: site['drain'] for site in params['allsites']}
+
+        submission = [{
+                'workflow': workflow,
+                'parameters': {
+                    'Action': 'acdc',
+                    'Reasons': ['AIEH'],
+                    'ACDCs': [],
+                    'Parameters': {
+                        step: {
+                            'memory': '',
+                            'cores': '',
+                            'sites': [site for site in sitelist if site_map.get(site) == 'enabled']
+                            }
+                        for step, sitelist in params['sitestorun'].items()
+                        }
+                    }
+                }]
+
+        if submission[0]['parameters']['Parameters']:
+            if dry:
+                print(submission)
+            else:
+                manageactions.submit2(user, submission)
+
+    @cherrypy.expose
+    def check_auto_acdc(self, key):
+
+        if key == serverconfig.config_dict()['actions']['key']:
+
+            user = serverconfig.config_dict()['aieh']['user']
+            dry = serverconfig.config_dict()['aieh'].get('dry')
+
+            for workflow in errorutils.assistance_manual():
+
+                if self.wkfparams(workflow).get('RequestType', 'Resubmission') == 'Resubmission' \
+                        or self.get_status(workflow) != 'none':
+                    continue
+
+                if evaluate.static(workflow) == 'acdc':
+                    self.auto_acdc(user, workflow, dry)
+
+            self.update_statuses()
+
+        return 'Done'
